@@ -147,11 +147,11 @@ INSIDE_VIRTUAL_ENV = in_virtualenv()
 
 
 def load_sample_data():
+    this_dir, _ = os.path.split(__file__)
+    path = this_dir + "/default_data/activemq-5.0.0.zip"
     if INSIDE_VIRTUAL_ENV:
         cwd = os.getcwd()
         path = cwd + '/pyexplainer/default_data/activemq-5.0.0.zip'
-    else:
-        path = 'default_data/activemq-5.0.0.zip'
     return pd.read_csv(path)
 
 
@@ -441,7 +441,7 @@ class PyExplainer:
         VIF_threshold : :obj:`int`
             Threshold value of VIF score.
         """
-        X_AS_train = AutoSpearman(correlation_threshold, correlation_method, VIF_threshold)
+        X_AS_train = AutoSpearman(self.X_train, correlation_threshold, correlation_method, VIF_threshold)
         if apply_to_X_train:
             self.set_X_train(X_AS_train)
             # if there is data of full feature names
